==> artemis_ui_kit-0.0.1.tar.gz: lib/src/Consts.dart <==
import 'package:flutter/material.dart';

class ArtemisColors {
  ArtemisColors._();

  static const Color primary = Color.fromRGBO(77,111,255,1);
  static const Color secondary = Color.fromRGBO(72,192,162,1);
  static const Color active = Color.fromRGBO(10,195,159,1);
  static const Color disable = Color.fromRGBO(255,93,93,1);
  static const Color texts = Color.fromRGBO(66,66,66,1);
  static const Color lineSeparators = Color.fromRGBO(235,235,235,1);
  static const Color activeSelector = Color.fromRGBO(239,241,254,1);
  static const Color mainBlurBackground = Color.fromRGBO(224,229,255,1);
  static const Color secondBlurBackground = Color.fromRGBO(220,247,244,1);

  //
  static const mainColor = Color.fromRGBO(244, 244, 244, 1);
  static const white1 = Color.fromRGBO(244, 244, 244, 1);
  static const white2 = Color.fromRGBO(255, 255, 255, 1);
  static const white3 = Color.fromRGBO(255, 255, 255, 1);
  static const white4 = Color.fromRGBO(250, 250, 250, 1);
  static const white5 = Color.fromRGBO(247, 247, 247, 1);
  static const black1 = Color.fromRGBO(52, 52, 52, 1);
  static const black = Color.fromRGBO(59, 59, 59, 1);
  static const black7 = Color.fromRGBO(0, 0, 0, 0.07);
  static const black8 = Color.fromRGBO(0, 0, 0, 0.08);
  static const blueGreen = Color.fromRGBO(20, 122, 137, 1);
  static const adobe = Color.fromRGBO(186, 112, 72, 1);
  static const oliveDrab = Color.fromRGBO(111, 108, 46, 1);
  static const paleGrey = Color.fromRGBO(247, 248, 255, 1);
  static const paleGreyTwo = Color.fromRGBO(239, 249, 255, 1);
  static const lightIshBlue = Color.fromRGBO(77, 111, 255, 1);
  static const veryLightBlue = Color.fromRGBO(221, 241, 244, 1);
  static const lightBlue = Color.fromRGBO(142, 219, 230, 1);
  static const lightPeach = Color.fromRGBO(255, 204, 177, 1);
  static const greenishBeige = Color.fromRGBO(208, 204, 114, 1);
  static const eggshell = Color.fromRGBO(244, 243, 225, 1);
  static const dullOrange = Color.fromRGBO(217, 152, 65, 1);
  static const aquaMarine = Color.fromRGBO(77, 204, 182, 0.1);
  static const darkMint = Color.fromRGBO(72, 192, 162, 1);
  static const brownGrey = Color.fromRGBO(141, 141, 141, 1);
  static const brownGrey2 = Color.fromRGBO(134, 134, 134, 1);
  static const brownGrey3 = Color.fromRGBO(173, 173, 173, 1);
  static const brownGrey4 = Color.fromRGBO(170, 170, 170, 1);
  static const brownGrey5 = Color.fromRGBO(130, 130, 130, 1);
  static const brownGrey6 = Color.fromRGBO(178, 178, 178, 1);
  static const brownGrey7 = Color.fromRGBO(175, 175, 175, 1);
  static const pinkishGrey = Color.fromRGBO(206, 206, 206, 1);
  static const paleGreyThree = Color.fromRGBO(241, 244, 255, 1);
  static const veryLightPink = Color.fromRGBO(237, 237, 237, 1);
  static const veryLightPink2 = Color.fromRGBO(234, 234, 234, 1);
  static const veryLightPink3 = Color.fromRGBO(235, 235, 235, 1);
  static const veryLightPink4 = Color.fromRGBO(242, 242, 242, 1);
  static const veryLightPink5 = Color.fromRGBO(195, 195, 195, 1);
  static const veryLightPink6 = Color.fromRGBO(225, 225, 225, 1);
  static const veryLightPink7 = Color.fromRGBO(255, 238, 237, 1);
  static const greenishTeal = Color.fromRGBO(46, 198, 157, 1);
  static const butterscotch = Color.fromRGBO(239, 176, 75, 1);
  static const turquoise = Color.fromRGBO(10, 195, 159, 1);
  static const grapefruit = Color.fromRGBO(255, 93, 93, 1);
  static const red = Color.fromRGBO(238, 91, 92, 1);
  static const lineColor = Color(0xffE1E1E1);
  static const ice = Color.fromRGBO(218, 250, 246, 1);
  static const iceBlue = Color.fromRGBO(248, 255, 253, 1);
}

class Styles {
  Styles._();

  static InputDecoration dropDownStyle = InputDecoration(
      contentPadding: EdgeInsets.only(left: 16, top: 2, bottom: 1),
      border: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.veryLightPink2),
      ),
      focusedBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.lightIshBlue),
      ),
      disabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.black),
      ),
      enabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.veryLightPink2),
      ));
  static InputDecoration dropDownStyleRequired = InputDecoration(
      labelStyle: TextStyle(color: ArtemisColors.darkMint),
      contentPadding: EdgeInsets.symmetric(horizontal: 16, vertical: 2),
      border: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.veryLightPink2),
      ),
      disabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.black),
      ),
      focusedBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.darkMint),
      ),
      enabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.darkMint),
      ));
  static InputDecoration textFieldStyle = InputDecoration(
    // labelStyle: TextStyle(color: MyColors.lightBlue),
      contentPadding: EdgeInsets.only(left: 16, top: 2, bottom: 1),
      border: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.veryLightPink2),
      ),
      focusedBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.lightIshBlue),
      ),
      disabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.black),
      ),

      enabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.veryLightPink2),
      ));
  static InputDecoration textFieldStyleInvalid = InputDecoration(
      labelStyle: TextStyle(color: ArtemisColors.red),
      contentPadding: EdgeInsets.symmetric(horizontal: 16, vertical: 2),
      border: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.red),
      ),
      disabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.black),
      ),
      focusedBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.red),
      ),
      enabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.red),
      ));
  static InputDecoration textFieldStyleConfirmed = InputDecoration(
      suffixIcon: Icon(
        Icons.check,
        size: 20,
        color: ArtemisColors.darkMint,
      ),
      labelStyle: TextStyle(color: ArtemisColors.darkMint),
      contentPadding: EdgeInsets.symmetric(horizontal: 16, vertical: 2),
      border: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.veryLightPink2),
      ),
      disabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.black),
      ),
      focusedBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.darkMint),
      ),
      enabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.darkMint),
      ));
  static InputDecoration textFieldStyleRequired = InputDecoration(
      labelStyle: TextStyle(color: ArtemisColors.darkMint),
      contentPadding: EdgeInsets.symmetric(horizontal: 16, vertical: 2),
      border: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.veryLightPink2),
      ),
      disabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.black),
      ),
      focusedBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.darkMint),
      ),
      enabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.darkMint),
      ));
}

class HexColor extends Color {
  static int _getColorFromHex(String hexColor) {
    hexColor = hexColor.toUpperCase().replaceAll("#", "");
    if (hexColor.length == 6) {
      hexColor = "FF" + hexColor;
    }
    return int.tryParse(hexColor, radix: 16)??int.parse("FFFFFFFF",radix: 16);
  }

  HexColor(final String hexColor) : super(_getColorFromHex(hexColor));
}

==> artemis_ui_kit-0.0.16.tar.gz: lib/src/Consts.dart <==
import 'package:flutter/material.dart';

class ArtemisColors {
  ArtemisColors._();

  static const Color primary = Color.fromRGBO(77, 111, 255, 1);
  static const Color secondary = Color.fromRGBO(72, 192, 162, 1);
  static const Color active = Color.fromRGBO(10, 195, 159, 1);
  static const Color disable = Color.fromRGBO(255, 93, 93, 1);
  static const Color texts = Color.fromRGBO(66, 66, 66, 1);
  static const Color lineSeparators = Color.fromRGBO(235, 235, 235, 1);
  static const Color activeSelector = Color.fromRGBO(239, 241, 254, 1);
  static const Color mainBlurBackground = Color.fromRGBO(224, 229, 255, 1);
  static const Color secondBlurBackground = Color.fromRGBO(220, 247, 244, 1);

  //
  static const mainColor = Color.fromRGBO(244, 244, 244, 1);
  static const white1 = Color.fromRGBO(244, 244, 244, 1);
  static const white2 = Color.fromRGBO(255, 255, 255, 1);
  static const white3 = Color.fromRGBO(255, 255, 255, 1);
  static const white4 = Color.fromRGBO(250, 250, 250, 1);
  static const white5 = Color.fromRGBO(247, 247, 247, 1);
  static const black1 = Color.fromRGBO(52, 52, 52, 1);
  static const black = Color.fromRGBO(59, 59, 59, 1);
  static const black7 = Color.fromRGBO(0, 0, 0, 0.07);
  static const black8 = Color.fromRGBO(0, 0, 0, 0.08);
  static const blueGreen = Color.fromRGBO(20, 122, 137, 1);
  static const adobe = Color.fromRGBO(186, 112, 72, 1);
  static const oliveDrab = Color.fromRGBO(111, 108, 46, 1);
  static const paleGrey = Color.fromRGBO(247, 248, 255, 1);
  static const paleGreyTwo = Color.fromRGBO(239, 249, 255, 1);
  static const lightIshBlue = Color.fromRGBO(77, 111, 255, 1);
  static const veryLightBlue = Color.fromRGBO(221, 241, 244, 1);
  static const lightBlue = Color.fromRGBO(142, 219, 230, 1);
  static const lightPeach = Color.fromRGBO(255, 204, 177, 1);
  static const greenishBeige = Color.fromRGBO(208, 204, 114, 1);
  static const eggshell = Color.fromRGBO(244, 243, 225, 1);
  static const dullOrange = Color.fromRGBO(217, 152, 65, 1);
  static const aquaMarine = Color.fromRGBO(77, 204, 182, 0.1);
  static const darkMint = Color.fromRGBO(72, 192, 162, 1);
  static const brownGrey = Color.fromRGBO(141, 141, 141, 1);
  static const brownGrey2 = Color.fromRGBO(134, 134, 134, 1);
  static const brownGrey3 = Color.fromRGBO(173, 173, 173, 1);
  static const brownGrey4 = Color.fromRGBO(170, 170, 170, 1);
  static const brownGrey5 = Color.fromRGBO(130, 130, 130, 1);
  static const brownGrey6 = Color.fromRGBO(178, 178, 178, 1);
  static const brownGrey7 = Color.fromRGBO(175, 175, 175, 1);
  static const pinkishGrey = Color.fromRGBO(206, 206, 206, 1);
  static const paleGreyThree = Color.fromRGBO(241, 244, 255, 1);
  static const veryLightPink = Color.fromRGBO(237, 237, 237, 1);
  static const veryLightPink2 = Color.fromRGBO(234, 234, 234, 1);
  static const veryLightPink3 = Color.fromRGBO(235, 235, 235, 1);
  static const veryLightPink4 = Color.fromRGBO(242, 242, 242, 1);
  static const veryLightPink5 = Color.fromRGBO(195, 195, 195, 1);
  static const veryLightPink6 = Color.fromRGBO(225, 225, 225, 1);
  static const veryLightPink7 = Color.fromRGBO(255, 238, 237, 1);
  static const greenishTeal = Color.fromRGBO(46, 198, 157, 1);
  static const butterscotch = Color.fromRGBO(239, 176, 75, 1);
  static const turquoise = Color.fromRGBO(10, 195, 159, 1);
  static const grapefruit = Color.fromRGBO(255, 93, 93, 1);
  static const red = Color.fromRGBO(238, 91, 92, 1);
  static const lineColor = Color(0xffE1E1E1);
  static const ice = Color.fromRGBO(218, 250, 246, 1);
  static const iceBlue = Color.fromRGBO(248, 255, 253, 1);
}

class Styles {
  Styles._();

  static InputDecoration dropDownStyle = InputDecoration(
      contentPadding: EdgeInsets.only(left: 16, top: 2, bottom: 1),
      border: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.veryLightPink2),
      ),
      focusedBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.lightIshBlue),
      ),
      disabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.black),
      ),
      enabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.veryLightPink2),
      ));
  static InputDecoration dropDownStyleRequired = InputDecoration(
      labelStyle: TextStyle(color: ArtemisColors.darkMint),
      contentPadding: EdgeInsets.symmetric(horizontal: 16, vertical: 2),
      border: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.veryLightPink2),
      ),
      disabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.black),
      ),
      focusedBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.darkMint),
      ),
      enabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.darkMint),
      ));
  static InputDecoration textFieldStyle = InputDecoration(
      // labelStyle: TextStyle(color: MyColors.lightBlue),
      contentPadding: EdgeInsets.only(left: 16, top: 2, bottom: 1),
      border: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.veryLightPink2),
      ),
      focusedBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.lightIshBlue),
      ),
      disabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.black),
      ),
      enabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.veryLightPink2),
      ));
  static InputDecoration textFieldStyleInvalid = InputDecoration(
      labelStyle: TextStyle(color: ArtemisColors.red),
      contentPadding: EdgeInsets.symmetric(horizontal: 16, vertical: 2),
      border: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.red),
      ),
      disabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.black),
      ),
      focusedBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.red),
      ),
      enabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.red),
      ));
  static InputDecoration textFieldStyleConfirmed = InputDecoration(
      suffixIcon: Icon(
        Icons.check,
        size: 20,
        color: ArtemisColors.darkMint,
      ),
      labelStyle: TextStyle(color: ArtemisColors.darkMint),
      contentPadding: EdgeInsets.symmetric(horizontal: 16, vertical: 2),
      border: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.veryLightPink2),
      ),
      disabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.black),
      ),
      focusedBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.darkMint),
      ),
      enabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.darkMint),
      ));
  static InputDecoration textFieldStyleRequired = InputDecoration(
      labelStyle: TextStyle(color: ArtemisColors.darkMint),
      contentPadding: EdgeInsets.symmetric(horizontal: 16, vertical: 2),
      border: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.veryLightPink2),
      ),
      disabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.black),
      ),
      focusedBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.darkMint),
      ),
      enabledBorder: OutlineInputBorder(
        borderRadius: BorderRadius.circular(5),
        borderSide: BorderSide(width: 1, color: ArtemisColors.darkMint),
      ));
}

class HexColor extends Color {
  static int _getColorFromHex(String hexColor) {
    hexColor = hexColor.toUpperCase().replaceAll("#", "");
    if (hexColor.length == 6) {
      hexColor = "FF" + hexColor;
    }
    return int.tryParse(hexColor, radix: 16) ??
        int.parse("FFFFFFFF", radix: 16);
  }

  HexColor(final String hexColor) : super(_getColorFromHex(hexColor));
}
